@@ -41,7 +41,11 @@ func setBindToDevSockopt(sc syscall.RawConn, device string) error {
 	return fmt.Errorf("binding connection to a device is not supported")
 }
 
-func dialerControl(logger log.Logger, network, address string, c syscall.RawConn, ttl, minTtl uint8, password string, bindInterface string) error {
+func setTCPMSSSockopt(conn *net.TCPConn, mss uint16) error {
+	return setTcpMSSSockopt(conn, mss)
+}
+
+func dialerControl(logger log.Logger, network, address string, c syscall.RawConn, ttl, minTtl uint8, mss uint16, password string, bindInterface string) error {
 	if password != "" {
 		logger.Warn("setting md5 for active connection is not supported",
 			log.Fields{
@@ -60,5 +64,11 @@ func dialerControl(logger log.Logger, network, address string, c syscall.RawConn
 				"Topic": "Peer",
 				"Key":   address})
 	}
+	if mss != 0 {
+		logger.Warn("setting MSS for active connection is not supported",
+			log.Fields{
+				"Topic": "Peer",
+				"Key":   address})
+	}
 	return nil
 }
